@@ -23,9 +23,9 @@
 
 #include "kcalcore_debug.h"
 
-#include <QtCore/QStringList>
-#include <QtCore/QTime>
-#include <QtCore/QVector>
+#include <QStringList>
+#include <QTime>
+#include <QVector>
 
 using namespace KCalCore;
 
@@ -437,11 +437,11 @@ KDateTime Constraint::intervalDateTime(RecurrenceRule::PeriodType type) const
         subdaily = false;
         break;
     case RecurrenceRule::rMonthly:
-        d.setYMD(year, month, 1);
+        d.setDate(year, month, 1);
         subdaily = false;
         break;
     case RecurrenceRule::rYearly:
-        d.setYMD(year, 1, 1);
+        d.setDate(year, 1, 1);
         subdaily = false;
         break;
     default:
@@ -1341,7 +1341,6 @@ bool RecurrenceRule::Private::buildCache() const
     // Build the list of all occurrences of this event (we need that to determine
     // the end date!)
     Constraint interval(getNextValidDateInterval(mDateStart, mPeriod));
-    QDateTime next;
 
     DateTimeList dts = datesForInterval(interval, mPeriod);
     // Only use dates after the event has started (start date is only included
